<?php
/**
 * Parse unit result from ztf.
 *
 * @param  array  $caseResults
 * @param  string $frame
 * @param  int    $productID
 * @param  int    $jobID
 * @param  int    $compileID
 * @access public
 * @return array
 */
public function parseZTFUnitResult($caseResults, $frame, $productID, $jobID, $compileID)
{
    $now        = helper::now();
    $cases      = array();
    $results    = array();
    $suites     = array();
    $caseTitles = array();
    $suiteNames = array();
    $suiteIndex = 0;
    foreach($caseResults as $caseIndex => $caseResult)
    {
        $suite = '';
        if(isset($caseResult->testSuite) and !isset($suiteNames[$caseResult->testSuite]))
        {
            $suite = new stdclass();
            $suite->product   = $productID;
            $suite->name      = $caseResult->testSuite;
            $suite->type      = 'unit';
            $suite->addedBy   = $this->app->user->account;
            $suite->addedDate = $now;

            $suiteNames[$suite->name] = $suite->name;
            $suiteIndex ++;
        }
        if(!isset($suites[$suiteIndex])) $suites[$suiteIndex] = $suite;

        $case = new stdclass();
        if(!empty($caseResult->id)) $case->id = $caseResult->id;
        $case->product    = $productID;
        if(empty($caseResult->id)) $case->title = $caseResult->title;
        $case->pri        = 3;
        $case->type       = 'unit';
        $case->stage      = 'unittest';
        $case->status     = 'normal';
        $case->openedBy   = $this->app->user->account;
        $case->openedDate = $now;
        $case->version    = 1;
        if(empty($caseResult->id)) $case->auto = 'unit';
        $case->frame      = $frame;

        $result = new stdclass();
        $result->case       = 0;
        $result->version    = 1;
        $result->caseResult = 'pass';
        $result->lastRunner = $this->app->user->account;
        $result->job        = $jobID;
        $result->compile    = $compileID;
        $result->date       = $now;
        $result->duration   = zget($caseResult, 'duration', 0);
        $result->stepResults[0]['result'] = 'pass';
        $result->stepResults[0]['real']   = '';
        if(!empty($caseResult->failure))
        {
            $result->caseResult = 'fail';
            $result->stepResults[0]['result'] = 'fail';
            $result->stepResults[0]['real']   = zget($caseResult->failure, 'desc', '');
        }
        $result->stepResults = serialize($result->stepResults);
        $case->lastRunner    = $this->app->user->account;
        $case->lastRunDate   = $now;
        $case->lastRunResult = $result->caseResult;

        $caseTitles[$suiteIndex][]        = $case->title;
        $cases[$suiteIndex][$caseIndex]   = $case;
        $results[$suiteIndex][$caseIndex] = $result;
    }

    return array('suites' => $suites, 'cases' => $cases, 'results' => $results, 'suiteNames' => $suiteNames, 'caseTitles' => $caseTitles);
}