<?php
include dirname(dirname(dirname(__FILE__))) . '/lib/restfulapi/entry.restful.class.php';
/**
 * The products entry point of ZenTaoPMS.
 *
 * @copyright   Copyright 2009-2021 青岛易软天创网络科技有限公司(QingDao Nature Easy Soft Network Technology Co,LTD, www.cnezsoft.com)
 * @license     ZPL(http://zpl.pub/page/zplv12.html) or AGPL(https://www.gnu.org/licenses/agpl-3.0.en.html)
 * @author      zhaoke <zhaoke@cnezsoft.com>
 * @package     entries
 * @version     1
 * @link        http://www.zentao.net
 */
class productsRestful extends entryRestful
{
    /**
     * GET method.
     *
     * @param  int    $projectID
     * @access public
     * @return void
     */
    public function get()
    {
        $control = $this->loadController('product', 'index');
        if(version_compare($this->config->version, '15.0', '>=') && version_compare($this->config->version, '16.0', '<='))
        {
            $control->all($this->param('status', 'all'), $this->param('order', 'order_asc'), 0, 10000);
        }
        else
        {
            $control->all(0, 0, $this->param('status', 'all'), $this->param('order', 'order_asc'), 0, 10000);
        }

        /* Response */
        $data = $this->getData();
        if (!$data or !isset($data->status)) return $this->sendError(400, 'error');
        if (isset($data->status) and $data->status == 'fail') return $this->sendError(400, $data->message);

        $products = $data->data->productStats;
        $result   = array();

        $accounts = array();
        foreach ($products as $product)
         {
            $product->id = intval($product->id);
            $accounts[$product->PO]        = $product->PO;
            $accounts[$product->QD]        = $product->QD;
            $accounts[$product->RD]        = $product->RD;
            $accounts[$product->createdBy] = $product->createdBy;
            if (isset($product->feedback)) $accounts[$product->feedback] = $product->feedback;
            if (!empty($product->mailto))
             {
                foreach (explode(',', $product->mailto) as $account)
                {
                    $account = trim($account);
                    if (empty($account)) continue;
                    $accounts[$account] = $account;
                }
            }

            $result[] = $this->format($product, 'createdDate:time,whitelist:userList,createdBy:user,PO:user,RD:user,QD:user');
        }

        $data = array();
        $data['total']    = count($result);
        $data['products'] = $result;

        $withUser = $this->param('withUser', '');
        if (!empty($withUser)) $data['users'] = $this->loadModel('user')->getListByAccounts($accounts, 'account');

        return $this->send(200, $data);
    }
}
